Index: trunk/stac/src/stac.h
===================================================================
--- trunk/stac/src/stac.h	(revision 2764)
+++ trunk/stac/src/stac.h	(revision 2783)
@@ -28,4 +28,5 @@
 					// considered bad
     float grad;				// Multiplier of the gradient
+    int nReject;			// Number of rejection iterations
 } stacConfig;
 
@@ -67,11 +68,13 @@
 // stacTransform.c
 
-// Transform input images
-psArray *stacTransform(const psArray *images, // Array of images to be transformed
-		       const psArray *maps, // Array of polynomials that do the transformation
-		       const psArray *errors, // Array of error images
-		       psArray **outErrors, // Array of output errors
-		       const psArray *masks, // Masks of input images
-		       const stacConfig *config	// Configuration
+// Transform input images, return success
+bool stacTransform(psArray **outputs,	// Transformed images for output
+		   psArray **outErrors, // Transformed error images for output
+		   const psArray *images, // Array of images to be transformed
+		   const psArray *maps, // Array of polynomials that do the transformation
+		   const psArray *errors, // Array of error images to be transformed
+		   const psArray *masks, // Masks of input images
+		   const psImage *region, // Region of interest for transformation
+		   const stacConfig *config // Configuration
     );
 
@@ -110,9 +113,11 @@
 
 // Combine the transformed images
-psImage *stacCombine(psArray *images,	// Array of transformed images
-		     psArray *errors,	// Array of transformed error images
-		     int nReject,	// Number of rejection iterations
-		     psArray **rejected, // Array of rejection masks
-		     stacConfig *config	// Configuration
+bool stacCombine(psImage **combined,	// The combined image for output
+		 psArray **rejected,	// Array of rejection masks
+		 psArray *images,	// Array of transformed images
+		 psArray *errors,	// Array of transformed error images
+		 int nReject,		// Number of rejection iterations
+		 psImage *region,	// Region to combine
+		 stacConfig *config	// Configuration
     );
 
